@@ -12,7 +12,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: oswlog.h,v 1.11 2005/01/26 00:52:16 mcr Exp $
  */
 
 #ifndef _OSWLOG_H_
@@ -21,6 +20,9 @@
 #include <openswan.h>
 #include <stdarg.h>
 #include <stdio.h>
+#if defined(NO_DEBUG)
+# include <stdlib.h> /* for abort() */
+#endif
 
 /* moved common code to library file */
 #include "openswan/passert.h"
@@ -49,7 +51,7 @@ extern void openswan_DBG_dump(const char *label, const void *p, size_t len);
 
 #define DBG_dump_chunk(label, ch) DBG_dump(label, (ch).ptr, (ch).len)
 
-extern void exit_tool(int);
+extern void exit_tool(int) NEVER_RETURNS;
 extern void tool_init_log(void);
 extern void tool_close_log(void);
 extern void set_debugging(lset_t deb);
