@@ -261,7 +261,6 @@ static char *connection_name (struct starter_conn *conn)
 	else {
 		return conn->name;
 	}
-	return conn->name;
 }
 
 static void set_whack_end(struct starter_config *cfg
@@ -475,6 +474,11 @@ static int starter_whack_basic_add_conn(struct starter_config *cfg
 	msg.addr_family = conn->left.addr_family;
 	msg.tunnel_addr_family = conn->left.addr_family;
 
+	if (conn->right.addrtype == KH_IPHOSTNAME)
+	{
+		msg.dnshostname = conn->right.strings[KSCF_IP];
+	}
+
 	msg.sa_ike_life_seconds = conn->options[KBF_IKELIFETIME];
 	msg.sa_ipsec_life_seconds = conn->options[KBF_SALIFETIME];
 	msg.sa_rekey_margin = conn->options[KBF_REKEYMARGIN];
@@ -487,6 +491,10 @@ static int starter_whack_basic_add_conn(struct starter_config *cfg
 
 	msg.metric = conn->options[KBF_METRIC];
 
+	if(conn->options_set[KBF_CONNMTU]) {
+		msg.connmtu   = conn->options[KBF_CONNMTU];
+	}
+
 	if(conn->options_set[KBF_DPDDELAY] &&
 	   conn->options_set[KBF_DPDTIMEOUT]) {
 		msg.dpd_delay   = conn->options[KBF_DPDDELAY];
@@ -522,6 +530,10 @@ static int starter_whack_basic_add_conn(struct starter_config *cfg
 		msg.remotepeertype=conn->options[KBF_REMOTEPEERTYPE];
 	}
 
+	if(conn->options_set[KBF_SHA2_TRUNCBUG]) {
+		msg.sha2_truncbug=conn->options[KBF_SHA2_TRUNCBUG];
+	}
+
 #ifdef HAVE_NM
 	/*Network Manager support*/
 	if(conn->options_set[KBF_NMCONFIGURED]) {
@@ -529,6 +541,20 @@ static int starter_whack_basic_add_conn(struct starter_config *cfg
 	}
 #endif
 
+
+#ifdef HAVE_LABELED_IPSEC
+	/*Labeled ipsec support*/
+	if(conn->options_set[KBF_LOOPBACK]) {
+		msg.loopback=conn->options[KBF_LOOPBACK];
+	}
+
+        if(conn->options_set[KBF_LABELED_IPSEC]) {
+                msg.labeled_ipsec=conn->options[KBF_LABELED_IPSEC];
+        }
+
+	msg.policy_label = conn->policy_label;
+#endif
+
 	set_whack_end(cfg, "left",  &msg.left, &conn->left);
 	set_whack_end(cfg, "right", &msg.right, &conn->right);
 
