@@ -39,6 +39,7 @@
 #include <sys/select.h>
 #endif
 
+#include "osw_select.h"
 #include "socketwrapper.h"
 #include "context_p.h"
 #include "assert_p.h"
@@ -349,7 +350,7 @@ lwres_context_sendrecv(lwres_context_t *ctx,
 {
 	lwres_result_t result;
 	int ret2;
-	fd_set readfds;
+	osw_fd_set readfds;
 	struct timeval timeout;
 
 	/*
@@ -367,9 +368,9 @@ lwres_context_sendrecv(lwres_context_t *ctx,
 	if (result != LWRES_R_SUCCESS)
 		return (result);
  again:
-	FD_ZERO(&readfds);
-	FD_SET(ctx->sock, &readfds);
-	ret2 = select(ctx->sock + 1, &readfds, NULL, NULL, &timeout);
+	OSW_FD_ZERO(&readfds);
+	OSW_FD_SET(ctx->sock, &readfds);
+	ret2 = osw_select(ctx->sock + 1, &readfds, NULL, NULL, &timeout);
 	
 	/*
 	 * What happened with select?
