@@ -2,8 +2,6 @@
  * Algorithm info parsing and creation functions
  * Author: JuanJo Ciarlante <jjo-ipsec@mendoza.gov.ar>
  *
- * alg_info.c,v 1.1.2.1 2003/11/21 18:12:23 jjo Exp
- *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
@@ -44,6 +42,7 @@
 struct oakley_group_desc;
 
 /* sadb/ESP aa attrib converters */
+/* Paul: but aa is two octets, is sadb? */
 enum ipsec_authentication_algo
 alg_info_esp_aa2sadb(enum ikev1_auth_attribute auth)
 {
@@ -52,7 +51,6 @@ alg_info_esp_aa2sadb(enum ikev1_auth_attribute auth)
 		    return AH_MD5;
 		case AUTH_ALGORITHM_HMAC_SHA1:
 		    return AH_SHA;
-
 		case AUTH_ALGORITHM_HMAC_SHA2_256:
 		    return AH_SHA2_256;
 		case AUTH_ALGORITHM_HMAC_SHA2_384:
@@ -86,6 +84,8 @@ alg_info_esp_v2tov1aa(enum ikev2_trans_type_integ ti)
 	return AUTH_ALGORITHM_HMAC_SHA1;
     case IKEv2_AUTH_HMAC_SHA2_256_128: 
 	return AUTH_ALGORITHM_HMAC_SHA2_256;
+    case IKEv2_AUTH_HMAC_SHA2_256_128_TRUNCBUG:
+	return AUTH_ALGORITHM_HMAC_SHA2_256_TRUNCBUG;
     case IKEv2_AUTH_HMAC_SHA2_384_192: 
 	return AUTH_ALGORITHM_HMAC_SHA2_256;
     case IKEv2_AUTH_HMAC_SHA2_512_256: 
@@ -112,6 +112,7 @@ alg_info_esp_sadb2aa(int sadb_aalg)
 {
 	int auth=0;
 	switch(sadb_aalg) {
+		/* Paul: why is this using a mix of SADB_AALG_* and AUTH_ALGORITHM_* */
 		case SADB_AALG_MD5HMAC:
 		case SADB_AALG_SHA1HMAC:
 			auth=sadb_aalg-1;
@@ -710,8 +711,21 @@ alg_info_parse_str (struct alg_info *alg_info
 
 	    case ST_END:
 	    case ST_EOF:
+		/*
+		 * If we detect sha2_256 with key size 96, we know they really meant
+		 * to configure sha2_256_trunc 256 bit with a hash truncation of 96
+		 */
+#warning paul check and redo me
+#if 0
+		if( !strncmp( ctx.aalg_buf, sha2_256, 8) && (ctx.eklen==0) && (ctx.aklen==96)) {
+		   DBG(DBG_CRYPT,DBG_log(" converting sha2_256-96 to sha2_256_trunc-256"));
+		   strncpy(ctx.aalg_buf, "sha2_256_trunc", sizeof("sha2_256_trunc"));
+		   ctx.aklen = 256;
+		}
+#endif
+
 		DBG(DBG_CRYPT, DBG_log("alg_info_parse_str() "
-				       "ealg_buf=%s aalg_buf=%s"
+				       "ealg_buf=%s aalg_buf=%s "
 				       "eklen=%d  aklen=%d",
 				       ctx.ealg_buf, ctx.aalg_buf,
 				       ctx.eklen, ctx.aklen));
