@@ -11,7 +11,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: alloc.c,v 1.2 2004/10/16 23:42:13 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -27,6 +26,9 @@
 #include "constants.h"
 #include "oswlog.h"
 
+/* leave enabled so support functions are always in libopenswan, and
+ * pluto can be recompiled with just the leak detective changes
+ */
 #define LEAK_DETECTIVE
 #include "oswalloc.h"
 
@@ -164,6 +166,8 @@ report_leaks(void)
 	*p = allocs,
 	*pprev = NULL;
     unsigned long n = 0;
+    unsigned long numleaks = 0;
+    unsigned long total = 0;
 
     while (p != NULL)
     {
@@ -175,12 +179,19 @@ report_leaks(void)
 	if (p == NULL || pprev->i.name != p->i.name)
 	{
 	    if (n != 1)
-		openswan_log("leak: %lu * %s, item size: %u", n, pprev->i.name, pprev->i.size);
+		openswan_log("leak: %lu * %s, item size: %lu", n, pprev->i.name, pprev->i.size);
 	    else
-		openswan_log("leak: %s, item size: %u", pprev->i.name, pprev->i.size);
+		openswan_log("leak: %s, item size: %lu", pprev->i.name, pprev->i.size);
+	    numleaks += n;
+	    total += pprev->i.size;
 	    n = 0;
 	}
     }
+    if(numleaks != 0)
+    	openswan_log("leak detective found %lu leaks, total size %lu",numleaks,total);
+    else
+    	openswan_log("leak detective found no leaks");
+
 }
 
 #endif /* !LEAK_DETECTIVE */
