@@ -338,6 +338,7 @@ allocate_RSA_public_key(const cert_t cert)
 	break;
     default:
 	openswan_log("RSA public key allocation error");
+	pfreeany(pk)
 	return NULL;
     }
 
@@ -572,6 +573,9 @@ struct secret *osw_find_secret_by_id(struct secret *secrets
 			same = same_RSA_public_key(&s->pks.u.RSA_private_key.pub
 						   , &best->pks.u.RSA_private_key.pub);
 			break;
+		    case PPK_XAUTH:
+			/* We don't support this yet, but no need to die */
+			break;
 		    default:
 			bad_case(kind);
 		    }
@@ -1249,11 +1253,11 @@ osw_process_secret_records(struct secret **psecrets, int verbose,
 	}
 	else
 	{
-	    struct secret *s = NULL;
+	    struct secret *s;
 
 	    /* expecting a list of indices and then the key info */
 	    s = alloc_thing(struct secret, "secret");
-	    
+
 	    s->ids = NULL;
 	    s->pks.kind = PPK_PSK;	/* default */
 	    setchunk(s->pks.u.preshared_secret, NULL, 0);
@@ -1317,9 +1321,9 @@ osw_process_secret_records(struct secret **psecrets, int verbose,
 		    s->ids = i;
 		    idtoa(&id, idb, IDTOA_BUF);
 		    DBG(DBG_CONTROL,
-			DBG_log("id type added to secret(%p) %d: %s",
+			DBG_log("id type added to secret(%p) %s: %s",
 				s,
-				s->pks.kind,
+				enum_name(&ppk_names,s->pks.kind),
 				idb));
 		}
 		if (!shift())
