@@ -12,7 +12,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ttoaddr.c,v 1.13 2005/08/05 17:36:24 mcr Exp $
  */
 #include "internal.h"
 #include "openswan.h"
@@ -471,8 +470,7 @@ ttoaddr_num(const char *src,
 			return "empty string";
 	} 
 
-	err_t err = ttoaddr_base(src, srclen, af, &numfailed, dst);
-	return err;
+	return ttoaddr_base(src, srclen, af, &numfailed, dst);
 }
 
 #ifdef TTOADDR_MAIN
