@@ -15,8 +15,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- *
- * RCSID $Id: x509.c,v 1.26 2005/09/13 19:43:19 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -203,13 +201,11 @@ load_authcerts(const char *type, const char *path, u_char auth_flags)
 
     if (chdir(path))
     {
-	char buff[256];
-	strerror_r(errno, buff, 256 );
-	openswan_log("Could not change to directory '%s': %s", path, buf);
+	openswan_log("Could not change to directory '%s': %s", path, strerror(errno));
     }
     else
     {
-	openswan_log("Changed path to directory '%s'", path);
+	DBG(DBG_CONTROL, DBG_log("Changed path to directory '%s'", path));
 	n = scandir(".", &filelist, (void *) file_select, alphasort);
 
 	if (n < 0){
