@@ -5,7 +5,7 @@
  * Copyright (C) 2000-2004 Andreas Steffen, Zuercher Hochschule Winterthur
  * Copyright (C) 2003-2008 Michael C Richardson <mcr@xelerance.com> 
  * Copyright (C) 2008 Antony Antony <antony@xelerance.com>
- * Copyright (C) 2003-2009 Paul Wouters <paul@xelerance.com> 
+ * Copyright (C) 2003-2010 Paul Wouters <paul@xelerance.com> 
  * Copyright (C) 2009 Avesh Agarwal <avagarwa@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -1205,7 +1205,7 @@ compute_digest(chunk_t tbs, int alg, chunk_t *digest)
 	    digest->len = SHA1_DIGEST_SIZE;
 	    return TRUE;
 	}
-#ifdef SHA2
+#ifdef USE_SHA2
 	case OID_SHA256:
 	case OID_SHA256_WITH_RSA:
 	{
@@ -1234,12 +1234,12 @@ compute_digest(chunk_t tbs, int alg, chunk_t *digest)
 #ifdef HAVE_LIBNSS
 	   unsigned int len;
 	   SECStatus s;
-	   s = PK11_DigestOp(ctx.ctx_nss, tbs.ptr, tbs.len);
+	   s = PK11_DigestOp(context.ctx_nss, tbs.ptr, tbs.len);
 	   passert(s==SECSuccess);
-	   s=PK11_DigestFinal(ctx.ctx_nss, digest->ptr, &len, SHA2_384_DIGEST_SIZE);
+	   s=PK11_DigestFinal(context.ctx_nss, digest->ptr, &len, SHA2_384_DIGEST_SIZE);
 	   passert(len==SHA2_384_DIGEST_SIZE);
 	   passert(s==SECSuccess);
-	   PK11_DestroyContext(ctx.ctx_nss, PR_TRUE);
+	   PK11_DestroyContext(context.ctx_nss, PR_TRUE);
 #else
 	   sha512_write(&context, tbs.ptr, tbs.len);
 	   sha512_final(&context);
@@ -1587,6 +1587,11 @@ gntoid(struct id *id, const generalName_t *gn)
 
 	    id->kind = afi->id_addr;
 	    ugh = initaddr(gn->name.ptr, gn->name.len, afi->af, &id->ip_addr);
+	    if (!ugh)
+		{
+		 openswan_log("Warning: gntoid() failed to initaddr(): %s", ugh);
+		}
+
 	}
 	break;
     case GN_RFC822_NAME:	/* ID type: ID_USER_FQDN */
@@ -1605,7 +1610,6 @@ gntoid(struct id *id, const generalName_t *gn)
 static generalName_t*
 parse_generalName(chunk_t blob, int level0)
 {
-    u_char buf[ASN1_BUF_LEN];
     asn1_ctx_t ctx;
     chunk_t object;
     unsigned int objectID = 0;
@@ -1631,6 +1635,7 @@ parse_generalName(chunk_t blob, int level0)
 	    break;
 	case GN_OBJ_DIRECTORY_NAME:
 	    DBG(DBG_PARSING,
+		u_char buf[ASN1_BUF_LEN];
 		dntoa((char *)buf, ASN1_BUF_LEN, object);
 		DBG_log("  '%s'", buf)
 	    )
@@ -1960,7 +1965,6 @@ parse_crlDistributionPoints(chunk_t blob, int level0)
 bool
 parse_x509cert(chunk_t blob, u_int level0, x509cert_t *cert)
 {
-    u_char  buf[ASN1_BUF_LEN];
     asn1_ctx_t ctx;
     bool critical;
     chunk_t object;
@@ -2000,6 +2004,7 @@ parse_x509cert(chunk_t blob, u_int level0, x509cert_t *cert)
 	case X509_OBJ_ISSUER:
 	    cert->issuer = object;
 	    DBG(DBG_PARSING,
+		u_char  buf[ASN1_BUF_LEN];
 		dntoa((char *)buf, ASN1_BUF_LEN, object);
 		DBG_log("  '%s'",buf));
 	    break;
@@ -2012,6 +2017,7 @@ parse_x509cert(chunk_t blob, u_int level0, x509cert_t *cert)
 	case X509_OBJ_SUBJECT:
 	    cert->subject = object;
 	    DBG(DBG_PARSING,
+		u_char  buf[ASN1_BUF_LEN];
 		dntoa((char *)buf, ASN1_BUF_LEN, object);
 		DBG_log("  '%s'",buf));
 	    break;
@@ -2117,7 +2123,6 @@ parse_x509cert(chunk_t blob, u_int level0, x509cert_t *cert)
 bool
 parse_x509crl(chunk_t blob, u_int level0, x509crl_t *crl)
 {
-    u_char buf[ASN1_BUF_LEN];
     asn1_ctx_t ctx;
     bool critical;
     chunk_t extnID;
@@ -2158,6 +2163,7 @@ parse_x509crl(chunk_t blob, u_int level0, x509crl_t *crl)
 	case CRL_OBJ_ISSUER:
 	    crl->issuer = object;
 	    DBG(DBG_PARSING,
+		u_char buf[ASN1_BUF_LEN];
 		dntoa((char *)buf, ASN1_BUF_LEN, object);
 		DBG_log("  '%s'",buf));
 	    break;
