@@ -1,6 +1,8 @@
 /* parsing packets: formats and tools
  * Copyright (C) 1997 Angelos D. Keromytis.
  * Copyright (C) 1998-2001  D. Hugh Redelmeier.
+ * Copyright (C) 2012 Avesh Agarwal <avagarwa@redhat.com>
+ * Copyright (C) 2012 Paul Wouters <pwouters@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -610,7 +612,7 @@ struct_desc isakmp_nat_oa = { "ISAKMP NAT-OA Payload", isanat_oa_fields, sizeof(
  */
 static field_desc ikev2generic_fields[] = {
     { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-    { ft_enum, 8/BITS_PER_BYTE, "critical bit", &critical_names},
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_end,  0, NULL, NULL }
 };
@@ -752,7 +754,7 @@ struct_desc ikev2_trans_attr_desc = {
  */
 static field_desc ikev2ke_fields[] = {
     { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-    { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_nat, 16/BITS_PER_BYTE, "transform type", &oakley_group_names },
     { ft_mbz, 16/BITS_PER_BYTE, NULL, NULL },
@@ -795,7 +797,7 @@ struct_desc ikev2_ke_desc = { "IKEv2 Key Exchange Payload",
 
 static field_desc ikev2id_fields[] = {
     { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-    { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_enum, 8/BITS_PER_BYTE, "id_type", &ident_names },
     { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
@@ -823,7 +825,7 @@ struct_desc ikev2_id_desc = { "IKEv2 Identification Payload",
  */
 static field_desc ikev2_cert_fields[] = {
   { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-  { ft_enum, 8/BITS_PER_BYTE, "critical bit", &critical_names },
+  { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
   { ft_len, 16/BITS_PER_BYTE, "length", NULL },
   { ft_enum, 8/BITS_PER_BYTE, "ikev2 cert encoding", &ikev2_cert_type_names },
   { ft_end,  0, NULL, NULL }
@@ -850,7 +852,7 @@ struct_desc ikev2_certificate_desc = { "IKEv2 Certificate Payload", ikev2_cert_f
 
 static field_desc ikev2_cert_req_fields[] = {
   { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-  { ft_enum, 8/BITS_PER_BYTE, "critical bit", &critical_names },
+  { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
   { ft_len, 16/BITS_PER_BYTE, "length", NULL },
   { ft_enum, 8/BITS_PER_BYTE, "ikev2 cert encoding", &ikev2_cert_type_names },
   { ft_end,  0, NULL, NULL }
@@ -878,7 +880,7 @@ struct_desc ikev2_certificate_req_desc = { "IKEv2 Certificate Request Payload",
  */
 static field_desc ikev2a_fields[] = {
     { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-    { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_enum, 8/BITS_PER_BYTE, "auth method", &ikev2_auth_names },
     { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
@@ -937,7 +939,7 @@ struct_desc ikev2_nonce_desc = { "IKEv2 Nonce Payload",
  */ 
 static field_desc ikev2_notify_fields[] = {
   { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-  { ft_enum, 8/BITS_PER_BYTE, "critical bit", &critical_names },
+  { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
   { ft_len, 16/BITS_PER_BYTE, "length", NULL },
   { ft_enum, 8/BITS_PER_BYTE, "Protocol ID", &protocol_names },
   /* names used are v1 names may be we should use 4306 3.3.1 names */
@@ -946,6 +948,37 @@ static field_desc ikev2_notify_fields[] = {
   { ft_end,  0, NULL, NULL }
 };
 
+/* IKEv2 Delete Payload
+ * layout from RFC 5996 Section 3.11 
+ * This is followed by a variable length SPI.
+ *
+ *                      1                   2                   3
+ *  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * ! Next Payload  !C| RESERVED    !         Payload Length        !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * !  Protocol ID  !   SPI Size    !           Num of SPIs         !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * !                                                               !
+ * ~               Security Parameter Index(es) (SPI)              ~
+ * !                                                               !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ */
+
+static field_desc ikev2_delete_fields[] = {
+    { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
+    { ft_len, 16/BITS_PER_BYTE, "length", NULL },
+    { ft_nat, 8/BITS_PER_BYTE, "protocol ID", NULL },
+    { ft_nat, 8/BITS_PER_BYTE, "SPI size", NULL },
+    { ft_nat, 16/BITS_PER_BYTE, "number of SPIs", NULL },
+    { ft_end, 0, NULL, NULL }
+};
+
+struct_desc ikev2_delete_desc = { "IKEv2 Delete Payload",
+                            ikev2_delete_fields, sizeof(struct ikev2_delete) };
+
+
 struct_desc ikev2_notify_desc = { "IKEv2 Notify Payload",
 			     ikev2_notify_fields, sizeof(struct ikev2_notify) };
 
@@ -993,14 +1026,14 @@ struct_desc ikev2_vendor_id_desc = { "IKEv2 Vendor ID Payload",
  */
 static field_desc ikev2ts_fields[] = {
     { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
-    { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
+    { ft_set, 8/BITS_PER_BYTE, "critical bit", critical_names},
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_nat,  8/BITS_PER_BYTE, "number of TS", NULL},
     { ft_mbz,  8/BITS_PER_BYTE, NULL, NULL },
     { ft_mbz, 16/BITS_PER_BYTE, NULL, NULL },
     { ft_end,  0, NULL, NULL }
 };
-struct_desc ikev2_ts_desc = { "IKEv2 Traffic Selectors",
+struct_desc ikev2_ts_desc = { "IKEv2 Traffic Selector Payload",
 			     ikev2ts_fields, sizeof(struct ikev2_ts) };
 
 
@@ -1026,14 +1059,14 @@ struct_desc ikev2_ts_desc = { "IKEv2 Traffic Selectors",
  *                Figure 20: Traffic Selector
  */
 static field_desc ikev2ts1_fields[] = {
-    { ft_enum, 8/BITS_PER_BYTE, "TS type", &ident_names },
+    { ft_enum, 8/BITS_PER_BYTE, "TS type", &ikev2_ts_type_names},
     { ft_nat,  8/BITS_PER_BYTE, "IP Protocol ID", NULL}, 
     { ft_len, 16/BITS_PER_BYTE, "length", NULL },
     { ft_nat, 16/BITS_PER_BYTE, "start port", NULL},
     { ft_nat, 16/BITS_PER_BYTE, "end port", NULL},
     { ft_end,  0, NULL, NULL }
 };
-struct_desc ikev2_ts1_desc = { "IKEv2 Traffic Selectors",
+struct_desc ikev2_ts1_desc = { "IKEv2 Traffic Selector",
 			       ikev2ts1_fields, sizeof(struct ikev2_ts1) };
 
 
@@ -1107,7 +1140,7 @@ struct_desc *const payload_descs[ISAKMP_NEXT_ROOF] = {
     &ikev2_a_desc,                      /* 39 */
     &ikev2_nonce_desc,                  /* 40 */
     &ikev2_notify_desc,                 /* 41 */
-    NULL,                               /* 42 */
+    &ikev2_delete_desc,                 /* 42 */
     &ikev2_vendor_id_desc,              /* 43 */
     &ikev2_ts_desc, &ikev2_ts_desc,     /* 44, 45 */
     &ikev2_e_desc,                      /* 46 */
@@ -1281,8 +1314,8 @@ in_struct(void *struct_ptr, struct_desc *sd
     if (ins->roof - cur < (ptrdiff_t)sd->size)
     {
         ugh = builddiag("not enough room in input packet for %s"
-                        " (remain=%d, sd->size=%d)"
-                        , sd->name, ins->roof - cur, sd->size);
+                        " (remain=%li, sd->size=%zu)"
+                        , sd->name, (long int)(ins->roof - cur), sd->size);
 
     }
     else
@@ -1330,6 +1363,7 @@ in_struct(void *struct_ptr, struct_desc *sd
 	    {
 		u_int32_t n = 0;
 
+		/* Reportedly fails on arm, see bug #775 */
 		for (; i != 0; i--)
 		    n = (n << BITS_PER_BYTE) | *cur++;
 
@@ -1432,7 +1466,7 @@ in_struct(void *struct_ptr, struct_desc *sd
     }
 
     /* some failure got us here: report it */
-    openswan_loglog(RC_LOG_SERIOUS, ugh);
+    openswan_loglog(RC_LOG_SERIOUS, "%s", ugh);
     return FALSE;
 }
 
@@ -1652,7 +1686,7 @@ out_struct(const void *struct_ptr, struct_desc *sd
     }
 
     /* some failure got us here: report it */
-    loglog(RC_LOG_SERIOUS, ugh);	/* ??? serious, but errno not relevant */
+    loglog(RC_LOG_SERIOUS, "%s", ugh);	/* ??? serious, but errno not relevant */
     return FALSE;
 }
 
