@@ -44,7 +44,11 @@
 #endif
 
 /* default number of ipsecX devices to create */
+#ifdef CONFIG_KLIPS_IF_NUM
+#define IPSEC_NUM_IF	CONFIG_KLIPS_IF_NUM
+#else
 #define IPSEC_NUM_IF	2
+#endif
 
 /* The field width must be < IF_NAM_SIZ - strlen("ipsec") - 1. */
 /* With "ipsec" being 5 characters, that means 10 is the max field width */
