@@ -36,13 +36,13 @@
 /* struct options; */
 
 #define __NO_VERSION__
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif	/* for CONFIG_IP_FORWARD */
 #ifdef CONFIG_MODULES
 #include <linux/module.h>
 #endif
-#include <linux/version.h>
 #include <openswan.h>
 
 #ifdef CONFIG_KLIPS_OCF
@@ -80,7 +80,8 @@ enum ipsec_rcv_value {
 	IPSEC_RCV_AUTHFAILED=-16,
 	IPSEC_RCV_REPLAYROLLED=-17,
 	IPSEC_RCV_BAD_DECRYPT=-18,
-	IPSEC_RCV_REALLYBAD=-19
+	IPSEC_RCV_REALLYBAD=-19,
+	IPSEC_RCV_ERRMEMALLOC=-20
 };
 
 /*
@@ -103,8 +104,9 @@ enum ipsec_rcv_value {
 
 struct ipsec_rcv_state {
 	struct sk_buff *skb;
+	struct sk_buff *pre_ipcomp_skb;/* skb before ipcomp was attempted */
 	struct net_device_stats *stats;
-	struct iphdr    *ipp;          /* the IP header */
+	void *iph;                     /* the IP header */
 	struct ipsec_sa *ipsp;         /* current SA being processed */
 	struct ipsec_sa *lastipsp;     /* last SA that was processed */
 	int len;                       /* length of packet */
@@ -150,12 +152,6 @@ struct ipsec_rcv_state {
 	int		next_state;
 	int		auth_checked;
 
-#ifdef CONFIG_KLIPS_OCF
-	struct work_struct	workq;
-#ifdef DECLARE_TASKLET
-	struct tasklet_struct	tasklet;
-#endif
-#endif
 #ifndef NET_21
 	struct net_device *devp;
 	struct inet_protocol *protop;
