@@ -27,8 +27,12 @@
 # define IP_SEND(skb, dev) \
 	ip_send(skb);
 
-
 #if defined(KLIPS)
+
+#define	osw_ip_hdr_version(ixirs)	(((struct iphdr *) (ixirs)->iph)->version)
+#define	osw_ip4_hdr(ixirs)	((struct iphdr *) (ixirs)->iph)
+#define	osw_ip6_hdr(ixirs)	((struct ipv6hdr *) (ixirs)->iph)
+
 /*
  * Heavily based on drivers/net/new_tunnel.c.  Lots
  * of ideas also taken from the 2.1.x version of drivers/net/shaper.c
@@ -57,8 +61,11 @@ struct ipsectunnelconf
 #ifndef KERNEL_VERSION
 #  define KERNEL_VERSION(x,y,z) (((x)<<16)+((y)<<8)+(z))
 #endif
+#define IPSECPRIV_MAGIC 0x15ECC0DE
 struct ipsecpriv
 {
+	uint32_t magic;
+
 	struct sk_buff_head sendq;
 	struct net_device *dev;
 	struct wait_queue *wait_queue;
@@ -98,6 +105,16 @@ struct ipsecpriv
 	int mtu;	/* What is the desired MTU? */
 };
 
+static inline struct ipsecpriv *netdev_to_ipsecpriv(const struct net_device *dev)
+{
+	struct ipsecpriv *iprv = netdev_priv(dev);
+
+	BUG_ON(!iprv);
+	BUG_ON(iprv->magic != IPSECPRIV_MAGIC);
+
+	return iprv;
+}
+
 extern char ipsec_tunnel_c_version[];
 
 extern struct net_device *ipsecdevices[IPSEC_NUM_IFMAX];
@@ -114,6 +131,19 @@ extern struct net_device *ipsec_get_device(int inst);
 
 extern int debug_tunnel;
 extern int sysctl_ipsec_debug_verbose;
+
+extern int osw_ipv6_find_hdr(const struct sk_buff *skb, unsigned int *offset, int target, unsigned short *fragoff);
+
+#ifdef CONFIG_KLIPS_IPV6
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,34)
+# define ICMP6_SEND(skb_in, type, code, info, dev) \
+	icmpv6_send(skb_in, type, code, htonl(info), dev)
+#else
+# define ICMP6_SEND(skb_in, type, code, info, dev) \
+	icmpv6_send(skb_in, type, code, htonl(info))
+#endif
+#endif /* CONFIG_KLIPS_IPV6 */
+
 #endif /* __KERNEL__ */
 
 #define DB_TN_INIT	0x0001
@@ -133,6 +163,6 @@ extern struct net_device *ipsec_tunnel_get_device(int vifnum);
 /* manage ipsec xmit state objects */
 extern int ipsec_xmit_state_cache_init (void);
 extern void ipsec_xmit_state_cache_cleanup (void);
-struct ipsec_xmit_state *ipsec_xmit_state_new (void);
+struct ipsec_xmit_state *ipsec_xmit_state_new (struct net_device *dev);
 void ipsec_xmit_state_delete (struct ipsec_xmit_state *ixs);
 
