@@ -25,9 +25,6 @@
 #endif
 #include "klips-crypto/aes_cbc.h"
 #include "klips-crypto/cbc_generic.h"
-#ifdef OCF_ASSIST
-#include "klips-crypto/ocf_assist.h"
-#endif
 
 /* returns bool success */
 int AES_set_key(aes_context *aes_ctx, const u_int8_t *key, int keysize) {
@@ -35,25 +32,7 @@ int AES_set_key(aes_context *aes_ctx, const u_int8_t *key, int keysize) {
 	return 1;	
 }
 
-#ifdef OCF_ASSIST
-
-CBC_IMPL_BLK16(_AES_cbc_encrypt, aes_context, u_int8_t *, aes_encrypt, aes_decrypt);
-
-int
-AES_cbc_encrypt(aes_context *ctx, const u_int8_t *in, u_int8_t *out, int ilen,
-		const u_int8_t *iv, int encrypt)
-{
-	if (ocf_aes_assist() & OCF_PROVIDES_AES) {
-		return ocf_aes_cbc_encrypt(ctx, in, out, ilen, iv, encrypt);
-	} else {
-		return _AES_cbc_encrypt(ctx, in, out, ilen, iv, encrypt);
-	}
-}
-
-#else
 CBC_IMPL_BLK16(AES_cbc_encrypt, aes_context, u_int8_t *, aes_encrypt, aes_decrypt);
-#endif
-
 
 /*
  * $Log: aes_cbc.c,v $
