@@ -13,10 +13,10 @@
  * for more details.
  */
 
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif
-#include <linux/version.h>
 
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -63,7 +63,9 @@
 #include "openswan/ipsec_ah.h"
 #include "openswan/ipsec_proto.h"
 
-#include "ipsec_ocf.h"
+#ifdef CONFIG_KLIPS_OCF
+# include "ipsec_ocf.h"
+#endif
 
 __u32 zeroes[AH_AMAX];
 
@@ -148,7 +150,7 @@ ipsec_rcv_ah_authcalc(struct ipsec_rcv_state *irs,
 	/* copy the initialized keying material */
 	memcpy(&tctx, irs->ictx, irs->ictx_len);
 
-	ipo = *irs->ipp;
+	ipo = *osw_ip4_hdr(irs);
 	ipo.tos = 0;	/* mutable RFC 2402 3.3.3.1.1.1 */
 	ipo.frag_off = 0;
 	ipo.ttl = 0;
@@ -193,7 +195,7 @@ ipsec_rcv_ah_decap(struct ipsec_rcv_state *irs)
 
 	ahhlen = AH_BASIC_LEN + (ahp->ah_hl << 2);
 
-	irs->ipp->tot_len = htons(ntohs(irs->ipp->tot_len) - ahhlen);
+	osw_ip4_hdr(irs)->tot_len = htons(ntohs(osw_ip4_hdr(irs)->tot_len) - ahhlen);
 	irs->next_header  = ahp->ah_nh;
 
 	/*
@@ -219,7 +221,7 @@ ipsec_rcv_ah_decap(struct ipsec_rcv_state *irs)
 	skb_pull(skb, ahhlen);
 
 	skb_set_network_header(skb, -irs->iphlen);
-	irs->ipp = ip_hdr(skb);
+	irs->iph = (void *) ip_hdr(skb);
 
 	ipsec_rcv_dmp("ah postpull", (void *)ip_hdr(skb), skb->len);
 
@@ -248,12 +250,12 @@ ipsec_xmit_ah_setup(struct ipsec_xmit_state *ixs)
   ahp->ah_spi = ixs->ipsp->ips_said.spi;
   ahp->ah_rpl = htonl(++(ixs->ipsp->ips_replaywin_lastseq));
   ahp->ah_rv = 0;
-  ahp->ah_nh = ixs->iph->protocol;
+  ahp->ah_nh = osw_ip4_hdr(ixs)->protocol;
   ahp->ah_hl = (sizeof(struct ahhdr) >> 2) - sizeof(__u64)/sizeof(__u32);
-  ixs->iph->protocol = IPPROTO_AH;
+  osw_ip4_hdr(ixs)->protocol = IPPROTO_AH;
   ipsec_xmit_dmp("ahp", (char*)ahp, sizeof(*ahp));
   
-  ipo = *ixs->iph;
+  ipo = *osw_ip4_hdr(ixs);
   ipo.tos = 0;
   ipo.frag_off = 0;
   ipo.ttl = 0;
