@@ -18,10 +18,10 @@
  * for more details.
  *
  */
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif
-#include <linux/version.h>
 
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -74,7 +74,7 @@
 #warning Compiling with limited ESP support ( K_SADB_EALG_MAX < 256 )
 #endif
 
-static rwlock_t ipsec_alg_lock = RW_LOCK_UNLOCKED;
+static DEFINE_RWLOCK(ipsec_alg_lock);
 #define IPSEC_ALG_HASHSZ	16	/* must be power of 2, even 2^0=1 */
 static struct list_head ipsec_alg_hash_table[IPSEC_ALG_HASHSZ];
 
@@ -902,13 +902,8 @@ int ipsec_alg_init(void) {
 	KLIPS_PRINT(1, "klips_info:ipsec_alg_init: "
 		"calling ipsec_alg_static_init()\n");
 
-	/* If we are suppose to use our AES, and don't have
-	 * CryptoAPI enabled...
-	 */
 #if defined(CONFIG_KLIPS_ENC_AES) && CONFIG_KLIPS_ENC_AES && !defined(CONFIG_KLIPS_ENC_AES_MODULE) 
-#if defined(CONFIG_KLIPS_ENC_CRYPTOAPI) && CONFIG_KLIPS_ENC_CRYPTOAPI
-#warning "Using built-in AES rather than CryptoAPI AES"
-#endif	
+	/* register our own AES code */
 	{
 		extern int ipsec_aes_init(void);
 		ipsec_aes_init();
@@ -916,9 +911,7 @@ int ipsec_alg_init(void) {
 #endif
 
 #if defined(CONFIG_KLIPS_ENC_3DES) && !defined(CONFIG_KLIPS_ENC_3DES_MODULE) 
-#if defined(CONFIG_KLIPS_ENC_CRYPTOAPI) && CONFIG_KLIPS_ENC_CRYPTOAPI
-#warning "Using built-in 3des rather than CryptoAPI 3des"
-#endif	
+	/* register our own 3DES code */
 	{
 		extern int ipsec_3des_init(void);
 		ipsec_3des_init();
