@@ -18,10 +18,10 @@
  *
  */
 
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif
-#include <linux/version.h>
 #include <linux/module.h>
 #include <linux/kernel.h> /* printk() */
 
@@ -100,6 +100,9 @@
 #include <openswan/pfkey.h>
 
 #if defined(NET_26) && defined(CONFIG_IPSEC_NAT_TRAVERSAL)
+# ifdef HAVE_UDP_ENCAP_CONVERT
+#  warning "You have CONFIG_IPSEC_NAT_TRAVERSAL set on a kernel > 2.6.22 that no longer need the NAT-T patch - you should recompile without it"
+# endif
 #include <net/xfrmudp.h>
 #endif
 
@@ -157,12 +160,30 @@ openswan_inet_add_protocol(struct inet_protocol *prot, unsigned protocol, char *
 	return err;
 }
 
+#ifdef CONFIG_KLIPS_IPV6
+static inline int
+openswan_inet6_add_protocol(struct inet6_protocol *prot, unsigned protocol, char *protstr)
+{
+	int err = inet6_add_protocol(prot, protocol);
+	if (err)
+		printk(KERN_ERR "KLIPS: can not register %s protocol - recompile with CONFIG_INET_%s disabled or as module\n", protstr,protstr);
+	return err;
+}
+#endif
+
 static inline int
 openswan_inet_del_protocol(struct inet_protocol *prot, unsigned protocol)
 {
 	return inet_del_protocol(prot, protocol);
 }
 
+#ifdef CONFIG_KLIPS_IPV6
+static inline int
+openswan_inet6_del_protocol(struct inet6_protocol *prot, unsigned protocol)
+{
+	return inet6_del_protocol(prot, protocol);
+}
+#endif
 #else
 static inline int
 openswan_inet_add_protocol(struct inet_protocol *prot, unsigned protocol, char*protstr)
@@ -217,16 +238,7 @@ ipsec_klips_init(void)
         if (error)
                 goto error_proc_init;
 
-#ifdef SPINLOCK
-	ipsec_sadb.sadb_lock = SPIN_LOCK_UNLOCKED;
-#else /* SPINLOCK */
-	ipsec_sadb.sadb_lock = 0;
-#endif /* SPINLOCK */
-
-#ifndef SPINLOCK
-	tdb_lock.lock = 0;
-	eroute_lock.lock = 0;
-#endif /* !SPINLOCK */
+	spin_lock_init(&ipsec_sadb.sadb_lock);
 
 	error |= ipsec_sadb_init();
         if (error)
@@ -256,6 +268,11 @@ ipsec_klips_init(void)
 	if (error)
 		goto error_openswan_inet_add_protocol_esp;
 
+#ifdef CONFIG_KLIPS_IPV6
+	error |= openswan_inet6_add_protocol(&esp6_protocol, IPPROTO_ESP, "ESP");
+	if (error)
+		goto error_openswan_inet6_add_protocol_esp;
+#endif
 #endif /* CONFIG_KLIPS_ESP */
 
 #ifdef CONFIG_KLIPS_AH
@@ -294,7 +311,9 @@ ipsec_klips_init(void)
 	/* register our ESP-UDP handler */
 	if(udp4_register_esp_rcvencap(klips26_rcv_encap
 				      , &klips_old_encap)!=0) {
-	   printk(KERN_ERR "KLIPS: can not register klips_rcv_encap function\n");
+	   printk(KERN_ERR "KLIPS: can not register klips26_rcv_encap function\n");
+	} else {
+	   KLIPS_PRINT(1, "KLIPS: registered klips26_rcv_encap function\n");
 	}
 #endif	
 
@@ -340,6 +359,10 @@ error_openswan_inet_add_protocol_comp:
 error_openswan_inet_add_protocol_ah:
 	openswan_inet_del_protocol(&ah_protocol, IPPROTO_AH);
 #endif
+#ifdef CONFIG_KLIPS_IPV6
+error_openswan_inet6_add_protocol_esp:
+	openswan_inet6_del_protocol(&esp6_protocol, IPPROTO_ESP);
+#endif
 error_openswan_inet_add_protocol_esp:
 	openswan_inet_del_protocol(&esp_protocol, IPPROTO_ESP);
 #endif
@@ -429,6 +452,11 @@ ipsec_cleanup(void)
  	if (openswan_inet_del_protocol(&esp_protocol, IPPROTO_ESP) < 0)
 		printk(KERN_INFO "klips_debug:ipsec_cleanup: "
 		       "esp close: can't remove protocol\n");
+#ifdef CONFIG_KLIPS_IPV6
+ 	if (openswan_inet6_del_protocol(&esp6_protocol, IPPROTO_ESP) < 0)
+		printk(KERN_INFO "klips_debug:ipsec_cleanup: "
+		       "esp6 close: can't remove protocol\n");
+#endif
 #endif /* CONFIG_KLIPS_ESP */
 
 #endif /* CONFIG_XFRM_ALTERNATE_STACK */
