@@ -18,10 +18,10 @@
  * for more details.
  */
 
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif
-#include <linux/version.h>
 #include <linux/kernel.h>
 
 #ifdef CONFIG_KLIPS_OCF
@@ -29,11 +29,14 @@
 #include <cryptodev.h>
 
 extern int  ipsec_ocf_sa_init(struct ipsec_sa *ipsp, int authalg, int encalg);
+extern int  ipsec_ocf_comp_sa_init(struct ipsec_sa *ipsp, int compalg);
 extern int  ipsec_ocf_sa_free(struct ipsec_sa *ipsp);
 extern enum ipsec_rcv_value ipsec_ocf_rcv(struct ipsec_rcv_state *irs);
 extern enum ipsec_xmit_value ipsec_ocf_xmit(struct ipsec_xmit_state *ixs);
 extern void	ipsec_ocf_init(void);
 
+#else
+# error This file should not be used without CONFIG_KLIPS_OCF, check MODULE_DEF_INCLUDE and MODULE_DEFCONFIG
 #endif
 
 /****************************************************************************/
