@@ -22,7 +22,7 @@
 #define __NO_VERSION__
 #include <linux/module.h>
 #include <linux/version.h>
-#ifndef AUTOCONF_INCLUDED
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 # include <linux/config.h>
 #endif
 #include <linux/kernel.h>
@@ -94,7 +94,7 @@
 extern struct proto_ops SOCKOPS_WRAPPED(pfkey_ops);
 
 #ifdef NET_26
-static rwlock_t pfkey_sock_lock = RW_LOCK_UNLOCKED;
+static DEFINE_RWLOCK(pfkey_sock_lock);
 HLIST_HEAD(pfkey_sock_list);
 static DECLARE_WAIT_QUEUE_HEAD(pfkey_sock_wait);
 static atomic_t pfkey_sock_users = ATOMIC_INIT(0);
@@ -110,7 +110,11 @@ struct socket_list *pfkey_registered_sockets[K_SADB_SATYPE_MAX+1];
 int pfkey_msg_interp(struct sock *, struct sadb_msg *);
 
 #ifdef NET_26_24_SKALLOC
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,38)
+DEBUG_NO_STATIC int pfkey_create(struct net *net, struct socket *sock, int protocol, int kern);
+#else
 DEBUG_NO_STATIC int pfkey_create(struct net *net, struct socket *sock, int protocol);
+#endif
 #else
 DEBUG_NO_STATIC int pfkey_create(struct socket *sock, int protocol);
 #endif
@@ -156,7 +160,9 @@ struct proto_ops SOCKOPS_WRAPPED(pfkey_ops) = {
 	mmap:		sock_no_mmap,
 };
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,39)
 #include <linux/smp_lock.h>
+#endif
 SOCKOPS_WRAP(pfkey, PF_KEY);
 
 #ifdef NET_26
@@ -638,7 +644,11 @@ static struct proto key_proto = {
 #endif
 #ifdef NET_26_24_SKALLOC
 DEBUG_NO_STATIC int
-pfkey_create(struct net *net, struct socket *sock, int protocol)
+pfkey_create(struct net *net, struct socket *sock, int protocol
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,38)
+	, int kern
+#endif
+)
 #else
 DEBUG_NO_STATIC int
 pfkey_create(struct socket *sock, int protocol)
@@ -668,6 +678,15 @@ pfkey_create(struct socket *sock, int protocol)
 		return -ESOCKTNOSUPPORT;
 	}
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,38)
+	if (!kern && !capable(CAP_NET_RAW)) {
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:pfkey_create: "
+			    "no permissions.\n");
+		return -EPERM;
+	}
+#endif
+
 	if(protocol != PF_KEY_V2) {
 		KLIPS_PRINT(debug_pfkey,
 			    "klips_debug:pfkey_create: "
@@ -720,11 +739,20 @@ pfkey_create(struct socket *sock, int protocol)
 /*	sk->num = protocol; */
 	sk->sk_protocol = protocol;
 	key_pid(sk) = current_uid();
+
+#ifdef HAVE_SOCKET_WQ
+	KLIPS_PRINT(debug_pfkey,
+		    "klips_debug:pfkey_create: "
+		    "sock->wq->fasync_list=0p%p sk_sleep(sk)=0p%p.\n",
+		    sock->wq->fasync_list,
+		    sk_sleep(sk));
+#else
 	KLIPS_PRINT(debug_pfkey,
 		    "klips_debug:pfkey_create: "
 		    "sock->fasync_list=0p%p sk->sleep=0p%p.\n",
 		    sock->fasync_list,
 		    sk->sk_sleep);
+#endif
 
 	pfkey_insert_socket(sk);
 	pfkey_list_insert_socket(sock, &pfkey_open_sockets);
@@ -1157,7 +1185,11 @@ pfkey_get_info(char *buffer, char **start, off_t offset, int length
 					sk,
 					key_pid(sk),
 					sock_flag(sk, SOCK_DEAD),
+#ifdef HAVE_SOCKET_WQ
+					sk->sk_wq,
+#else
 					sk->sk_sleep,
+#endif
 					sk->sk_socket,
 					sk->sk_err,
 					sk->sk_reuse,
@@ -1441,11 +1473,11 @@ pfkey_init(void)
 	};
 	static struct ipsec_alg_supported supported_init_ipip[] = {
 		{K_SADB_EXT_SUPPORTED_ENCRYPT, K_SADB_X_TALG_IPv4_in_IPv4, 0, 32, 32}
-#if defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE)
+#if defined(CONFIG_KLIPS_IPV6)
 		, {K_SADB_EXT_SUPPORTED_ENCRYPT, K_SADB_X_TALG_IPv6_in_IPv4, 0, 128, 32}
 		, {K_SADB_EXT_SUPPORTED_ENCRYPT, K_SADB_X_TALG_IPv4_in_IPv6, 0, 32, 128}
 		, {K_SADB_EXT_SUPPORTED_ENCRYPT, K_SADB_X_TALG_IPv6_in_IPv6, 0, 128, 128}
-#endif /* defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE) */
+#endif /* defined(CONFIG_KLIPS_IPV6) */
 	};
 #ifdef CONFIG_KLIPS_IPCOMP
 	static struct ipsec_alg_supported supported_init_ipcomp[] = {
