@@ -12,21 +12,18 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2_ext_bits.c,v 1.22 2005/05/11 01:45:31 mcr Exp $
  */
 
 /*
  *		Template from klips/net/ipsec/ipsec/ipsec_parse.c.
  */
 
-char pfkey_v2_ext_bits_c_version[] = "$Id: pfkey_v2_ext_bits.c,v 1.22 2005/05/11 01:45:31 mcr Exp $";
-
 /*
  * Some ugly stuff to allow consistent debugging code for use in the
  * kernel and in user space
 */
 
-#if defined(__KERNEL__) && defined(linux)
+#if defined(__KERNEL__) && (defined(linux) || defined(__linux__))
 
 # include <linux/kernel.h>  /* for printk */
 
@@ -43,9 +40,9 @@ char pfkey_v2_ext_bits_c_version[] = "$Id: pfkey_v2_ext_bits.c,v 1.22 2005/05/11
 # include <linux/netdevice.h>   /* struct device, and other headers */
 # include <linux/etherdevice.h> /* eth_type_trans */
 # include <linux/ip.h>          /* struct iphdr */ 
-# if defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE)
+# if defined(CONFIG_KLIPS_IPV6)
 #  include <linux/ipv6.h>
-# endif /* defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE) */
+# endif /* defined(CONFIG_KLIPS_IPV6) */
 
 #else /* __KERNEL__ */
 
