@@ -1,5 +1,3 @@
-char radij_c_version[] = "RCSID $Id: radij.c,v 1.48 2005/04/29 05:10:22 mcr Exp $";
-
 /*
  * This file is defived from ${SRC}/sys/net/radix.c of BSD 4.4lite
  *
@@ -55,10 +53,10 @@ char radij_c_version[] = "RCSID $Id: radij.c,v 1.48 2005/04/29 05:10:22 mcr Exp
  * Routines to build and maintain radix trees for routing lookups.
  */
 
-#ifndef AUTOCONF_INCLUDED
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) && !defined(AUTOCONF_INCLUDED)
 #include <linux/config.h>
 #endif
-#include <linux/version.h>
 #include <linux/kernel.h> /* printk() */
 
 #include "openswan/ipsec_param.h"
@@ -452,6 +450,10 @@ rj_addmask(n_arg, search, skip)
 #if 0
 struct radij_node *
 #endif
+
+unsigned char *dumper;
+int dumper_len;
+
 int
 rj_addroute(v_arg, n_arg, head, treenodes)
 	void *v_arg, *n_arg;
